# SessionCommand

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | 
**created_at** | **datetime** |  | 
**name** | **str** |  | 
**params** | [**object**](.md) |  | 
**shell** | **bool** |  | 
**shell_command** | **str** |  | 
**message** | **str** |  | [optional] 
**killed_at** | **datetime** |  | [optional] 
**finished_at** | **datetime** |  | [optional] 
**status_code** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


